@@ -99,10 +99,9 @@ def run_new_model(args):
             "project name is not detected. are you inside your project folder?"
         )
 
-    model_name = args.model_name[0].lower()
-    class_name = ""
-    for i, sym in enumerate(model_name):
-        class_name += sym.upper() if i == 0 else sym
+    class_name = args.model_name[0]
+    model_filename = snake_case(class_name) + ".py"
+    model_filename = os.path.join(project_name, f"models/{model_filename}")
 
     fields = []
     for field_desc in args.fields:
@@ -120,7 +119,6 @@ def run_new_model(args):
     with open(tmplfilename) as tmplfile:
         tmpl = jinja2.Template(tmplfile.read())
 
-    model_filename = os.path.join(project_name, f"models/{model_name}.py")
     os.makedirs(os.path.dirname(model_filename), exist_ok=True)
     with open(model_filename, "w") as modelf:
         modelf.write(
