@@ -1,20 +1,19 @@
 from flask import Blueprint, g
+from inspect import isclass
 from .errors import AuthenticationError
 
 
 class Controller(Blueprint):
-    def __init__(
-        self, name, import_name, require_auth=True, auth_error_class=None, **kwargs
-    ):
+
+    auth_error = AuthenticationError
+
+    def __init__(self, name, import_name, require_auth=True, **kwargs):
         super().__init__(name, import_name, **kwargs)
 
-        if auth_error_class is None:
-            auth_error_class = AuthenticationError
-        if type(auth_error_class) != type or not issubclass(
-            auth_error_class, Exception
-        ):
-            raise TypeError("auth_error_class must be a subclass of Exception")
-        self.auth_error = auth_error_class
+        if not isclass(self.auth_error) or not issubclass(self.auth_error, Exception):
+            raise TypeError(
+                f"{self.__class__.__name__}.auth_error must be a subclass of Exception"
+            )
 
         self.before_request(self.__set_auth_data)
         if require_auth:
