@@ -6,6 +6,7 @@ from ..context import ctx
 
 from .base_queue import BaseQueue, DEFAULT_ACK_TIMEOUT, DEFAULT_RETRIES
 from .task import BaseTask, TaskSendError
+from glasskit import json
 
 
 class RedisQueue(BaseQueue):
@@ -73,8 +74,6 @@ class RedisQueue(BaseQueue):
         return None
 
     def _enqueue(self, task):
-        from flask import json
-
         ack = None
         ackps = self.ackconn.pubsub(ignore_subscribe_messages=True)
         retries = self.retries
@@ -125,8 +124,6 @@ class RedisQueue(BaseQueue):
 
     @property
     def tasks(self):
-        from flask import json
-
         self.subscribe()
         for redismsg in self.ps.listen():
             try:
